config

package
v0.0.0-...-a1b8ec1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 5, 2023 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

Package config takes care of loading and exposing user configuration.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	HTTPPort       string        `config:"http_port,short=p"`
	SteamAPIKey    string        `config:"steam_api_key,required"`
	SteamID        string        `config:"steam_id"`
	SteamName      string        `config:"steam_name"`
	FetchInventory bool          `config:"fetch_inventory"`
	Currency       string        `config:"currency"`
	ScrapeInterval time.Duration `config:"scrape_interval,short=i,description=scrape interval in seconds"`
}

Config is the exporter configuration.

func Load

func Load() *Config

Load method loads the configuration by using environment variables.

func (Config) Show

func (c Config) Show()

Show method displays all the load configuration

Jump to